@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,7 +11,7 @@ func FreshbooksAccessToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "freshbooks-access-token",
 		Description: "Discovered a Freshbooks Access Token, posing a risk to accounting software access and sensitive financial data exposure.",
-		Regex:       generateSemiGenericRegex([]string{"freshbooks"}, alphaNumeric("64"), true),
+		Regex:       utils.GenerateSemiGenericRegex([]string{"freshbooks"}, utils.AlphaNumeric("64"), true),
 
 		Keywords: []string{
 			"freshbooks",
@@ -19,7 +20,7 @@ func FreshbooksAccessToken() *config.Rule {
 
 	// validate
 	tps := []string{
-		generateSampleSecret("freshbooks", secrets.NewSecret(alphaNumeric("64"))),
+		utils.GenerateSampleSecret("freshbooks", secrets.NewSecret(utils.AlphaNumeric("64"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
