@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,8 +11,8 @@ func OktaAccessToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "okta-access-token",
 		Description: "Identified an Okta Access Token, which may compromise identity management services and user authentication data.",
-		Regex: generateSemiGenericRegex([]string{"okta"},
-			alphaNumericExtended("42"), true),
+		Regex: utils.GenerateSemiGenericRegex([]string{"okta"},
+			utils.AlphaNumericExtended("42"), true),
 
 		Keywords: []string{
 			"okta",
@@ -20,7 +21,7 @@ func OktaAccessToken() *config.Rule {
 
 	// validate
 	tps := []string{
-		generateSampleSecret("okta", secrets.NewSecret(alphaNumeric("42"))),
+		utils.GenerateSampleSecret("okta", secrets.NewSecret(utils.AlphaNumeric("42"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
