@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,8 +11,8 @@ func RapidAPIAccessToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "rapidapi-access-token",
 		Description: "Uncovered a RapidAPI Access Token, which could lead to unauthorized access to various APIs and data services.",
-		Regex: generateSemiGenericRegex([]string{"rapidapi"},
-			alphaNumericExtendedShort("50"), true),
+		Regex: utils.GenerateSemiGenericRegex([]string{"rapidapi"},
+			utils.AlphaNumericExtendedShort("50"), true),
 
 		Keywords: []string{
 			"rapidapi",
@@ -20,8 +21,8 @@ func RapidAPIAccessToken() *config.Rule {
 
 	// validate
 	tps := []string{
-		generateSampleSecret("rapidapi",
-			secrets.NewSecret(alphaNumericExtendedShort("50"))),
+		utils.GenerateSampleSecret("rapidapi",
+			secrets.NewSecret(utils.AlphaNumericExtendedShort("50"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
